==> spip_2.0.8.orig.tar.gz: spip-2.0.8.orig/ecrire/lang/public_cs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Hlavn&iacute; strana',
'articles' => '&#268;l&aacute;nky',
'articles_auteur' => '&#268;l&aacute;nky tohoto autora',
'articles_populaires' => 'Nej&#269;ten&#283;j&#353;&iacute; &#269;l&aacute;nky',
'articles_rubrique' => '&#268;l&aacute;nky v t&eacute;to rubrice',
'aucun_article' => 'Na t&eacute;to adrese nen&iacute; &#382;&aacute;dn&yacute; &#269;l&aacute;nek',
'aucun_auteur' => 'Na t&eacute;to adrese nen&iacute; &#382;&aacute;dn&yacute; autor',
'aucun_site' => 'Na t&eacute;to adrese nen&iacute; &#382;&aacute;dn&yacute; odkaz',
'aucune_breve' => 'Na t&eacute;to adrese nen&iacute; &#382;&aacute;dn&aacute; novinka',
'aucune_rubrique' => 'Na t&eacute;to adrese nen&iacute; &#382;&aacute;dn&aacute; rubrika',
'autres_breves' => 'Dal&#353;&iacute; novinky',
'autres_groupes_mots_clefs' => 'Dal&#353;&iacute; skupiny kl&iacute;&#269;ov&yacute;ch slov',
'autres_sites' => 'Dal&#353;&iacute; odkazy',

// B
'bonjour' => 'Dobr&yacute; den',
'breves' => 'Novinky',

// C
'commenter_site' => 'Koment&aacute;&#345; k tomuto odkazu',

// D
'date' => 'Datum',
'dernier_ajout' => 'Posledn&iacute; p&#345;&iacute;sp&#283;vky',
'dernieres_breves' => 'Posledn&iacute; novinky',
'derniers_articles' => 'Posledn&iacute; &#269;l&aacute;nky',
'derniers_commentaires' => 'Posledn&iacute; koment&aacute;&#345;e',
'derniers_messages_forum' => 'Posledn&iacute; p&#345;&iacute;sp&#283;vky v diskusn&iacute;ch f&oacute;rech',

// E
'edition_mode_texte' => 'Textov&yacute; re&#382;im',
'en_reponse' => 'Odpov&#283;&#271; na:',
'en_resume' => 'Shrnut&iacute;',
'envoyer_message' => 'Odeslat zpr&aacute;vu',
'espace_prive' => 'Vstup pro autory',

// F
'forum' => 'F&oacute;rum',

// H
'hierarchie_site' => 'Struktura str&aacute;nek',

// J
'jours' => 'dn&#367;',

// M
'meme_auteur' => 'Od stejn&eacute;ho autora',
'meme_rubrique' => 'Ve stejn&eacute; rubrice',
'memes_auteurs' => 'Od stejn&yacute;ch autor&#367;',
'message' => 'Zpr&aacute;va',
'messages_forum' => 'Zpr&aacute;vy v diskusn&iacute;m f&oacute;ru',
'messages_recents' => 'Posledn&iacute; zpr&aacute;vy v diskusn&iacute;ch f&oacute;rech',
'mots_clefs' => 'Kl&iacute;&#269;ov&aacute; slova',
'mots_clefs_meme_groupe' => 'Kl&iacute;&#269;ov&aacute; slova ve stejn&eacute; skupin&#283;',

// N
'navigation' => 'Navigace',
'nom' => 'Jm&eacute;no',
'nouveautes' => 'Co je nov&eacute;ho',
'nouveautes_web' => 'Novinky na webu',
'nouveaux_articles' => 'Nov&eacute; &#269;l&aacute;nky',
'nouvelles_breves' => 'Nov&eacute; novinky',

// P
'page_precedente' => 'p&#345;edchoz&iacute; strana',
'page_suivante' => 'dal&#353;&iacute; strana',
'par_auteur' => 'napsal(a)',
'participer_site' => 'M&#367;&#382;ete se aktivn&#283; zapojit a napsat n&#283;jak&yacute; &#269;l&aacute;nek pro tento web - zaregistrujte se n&iacute;&#382;e. Okam&#382;it&#283; obdr&#382;&iacute;te e-mail s p&#345;&iacute;stupov&yacute;mi k&oacute;dy do &#269;&aacute;sti pro autory.',
'plan_site' => 'Mapa str&aacute;nek',
'popularite' => 'Popularita',
'poster_message' => 'Napsat zpr&aacute;vu',
'proposer_site' => 'M&#367;&#382;ete navrhnout odkaz, kter&yacute; m&aacute; b&yacute;t za&#345;azen do t&eacute;to rubriky:',

// R
'repondre_article' => 'Reagovat na tento &#269;l&aacute;nek',
'repondre_breve' => 'Reagovat na tuto novinku ',
'repondre_message' => 'Reagovat na tuto zpr&aacute;vu',
'resultats_recherche' => 'V&yacute;sledky hled&aacute;n&iacute;',
'retour_debut_forums' => 'Zp&#283;t na za&#269;&aacute;tek diskusn&iacute;ch f&oacute;r',
'rubrique' => 'Rubrika',
'rubriques' => 'Rubriky',

// S
'signatures_petition' => 'Podpisy',
'site_realise_avec_spip' => 'Str&aacute;nky vytvo&#345;eny pomoc&iacute; SPIP',
'sites_web' => 'Odkazy',
'sous_rubriques' => 'Podrubriky',
'suite' => 'pokra&#269;ov&aacute;n&iacute;',
'sur_web' => 'Na webu',
'syndiquer_rubrique' => 'Zahrnout tuto rubriku',
'syndiquer_site' => 'Zahrnout cel&yacute; web',

// T
'texte_lettre_information' => 'Zde je zpravodaj tohoto webu',
'texte_lettre_information_2' => 'Tento soupis sumarizuje &#269;l&aacute;nky a novinky publikovan&eacute; od ',

// V
'ver_imprimer' => 'Verze pro tisk',
'voir_en_ligne' => 'Pod&iacute;vejte se online',
'voir_squelette' => 'Zobrazit &#353;ablonu t&eacute;to str&aacute;nky'
);

?>

==> spip_2.1.orig.tar.gz: spip-2.1.orig/ecrire/lang/public_cs.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Hlavn&iacute; strana',
'article' => 'Article', # NEW
'articles' => '&#268;l&aacute;nky',
'articles_auteur' => '&#268;l&aacute;nky tohoto autora',
'articles_populaires' => 'Nej&#269;ten&#283;j&#353;&iacute; &#269;l&aacute;nky',
'articles_rubrique' => '&#268;l&aacute;nky v t&eacute;to rubrice',
'aucun_article' => 'Na t&eacute;to adrese nen&iacute; &#382;&aacute;dn&yacute; &#269;l&aacute;nek',
'aucun_auteur' => 'Na t&eacute;to adrese nen&iacute; &#382;&aacute;dn&yacute; autor',
'aucun_site' => 'Na t&eacute;to adrese nen&iacute; &#382;&aacute;dn&yacute; odkaz',
'aucune_breve' => 'Na t&eacute;to adrese nen&iacute; &#382;&aacute;dn&aacute; novinka',
'aucune_rubrique' => 'Na t&eacute;to adrese nen&iacute; &#382;&aacute;dn&aacute; rubrika',
'auteur' => 'Auteur', # NEW
'autres' => 'Ostatn&iacute;',
'autres_breves' => 'Dal&#353;&iacute; novinky',
'autres_groupes_mots_clefs' => 'Dal&#353;&iacute; skupiny kl&iacute;&#269;ov&yacute;ch slov',
'autres_sites' => 'Dal&#353;&iacute; odkazy',

// B
'bonjour' => 'Dobr&yacute; den',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'Novinky',

// C
'commenter_site' => 'Koment&aacute;&#345; k tomuto odkazu',
'copie_document_impossible' => 'Dokument nen&iacute; mo&#382;n&eacute; kop&iacute;rovat',

// D
'date' => 'Datum',
'dernier_ajout' => 'Posledn&iacute; p&#345;&iacute;sp&#283;vky',
'dernieres_breves' => 'Posledn&iacute; novinky',
'derniers_articles' => 'Posledn&iacute; &#269;l&aacute;nky',
'derniers_commentaires' => 'Posledn&iacute; koment&aacute;&#345;e',
'derniers_messages_forum' => 'Posledn&iacute; p&#345;&iacute;sp&#283;vky v diskusn&iacute;ch f&oacute;rech',
'documents_interdits_forum' => 'Dokumenty jsou ve f&oacute;ru zak&aacute;zan&eacute;',

// E
'edition_mode_texte' => 'Textov&yacute; re&#382;im',
'en_reponse' => 'Odpov&#283;&#271; na:',
'en_resume' => 'Shrnut&iacute;',
'envoyer_message' => 'Odeslat zpr&aacute;vu',
'espace_prive' => 'Vstup pro autory',

// F
'formats_acceptes' => 'Povolen&eacute; form&aacute;ty: @formats@.',
'forum' => 'F&oacute;rum',

// H
'hierarchie_site' => 'Struktura str&aacute;nek',

// J
'jours' => 'dn&#367;',

// L
'lien_connecter' => 'P&#345;ihl&aacute;&#353;en&iacute;',

// M
'meme_auteur' => 'Od stejn&eacute;ho autora',
'meme_rubrique' => 'Ve stejn&eacute; rubrice',
'memes_auteurs' => 'Od stejn&yacute;ch autor&#367;',
'message' => 'Zpr&aacute;va',
'messages_forum' => 'Zpr&aacute;vy v diskusn&iacute;m f&oacute;ru',
'messages_recents' => 'Posledn&iacute; zpr&aacute;vy v diskusn&iacute;ch f&oacute;rech',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'Kl&iacute;&#269;ov&aacute; slova',
'mots_clefs_meme_groupe' => 'Kl&iacute;&#269;ov&aacute; slova ve stejn&eacute; skupin&#283;',

// N
'navigation' => 'Navigace',
'nom' => 'Jm&eacute;no',
'nouveautes' => 'Co je nov&eacute;ho',
'nouveautes_web' => 'Novinky na webu',
'nouveaux_articles' => 'Nov&eacute; &#269;l&aacute;nky',
'nouvelles_breves' => 'Nov&eacute; novinky',

// P
'page_precedente' => 'p&#345;edchoz&iacute; strana',
'page_suivante' => 'dal&#353;&iacute; strana',
'par_auteur' => 'napsal(a)',
'participer_site' => 'M&#367;&#382;ete se aktivn&#283; zapojit a napsat n&#283;jak&yacute; &#269;l&aacute;nek pro tento web - zaregistrujte se n&iacute;&#382;e. Okam&#382;it&#283; obdr&#382;&iacute;te e-mail s p&#345;&iacute;stupov&yacute;mi k&oacute;dy do &#269;&aacute;sti pro autory.',
'plan_site' => 'Mapa str&aacute;nek',
'popularite' => 'Popularita',
'poster_message' => 'Napsat zpr&aacute;vu',
'proposer_site' => 'M&#367;&#382;ete navrhnout odkaz, kter&yacute; m&aacute; b&yacute;t za&#345;azen do t&eacute;to rubriky:',

// R
'repondre_article' => 'Reagovat na tento &#269;l&aacute;nek',
'repondre_breve' => 'Reagovat na tuto novinku ',
'repondre_message' => 'Reagovat na tuto zpr&aacute;vu',
'resultats_recherche' => 'V&yacute;sledky hled&aacute;n&iacute;',
'retour_debut_forums' => 'Zp&#283;t na za&#269;&aacute;tek diskusn&iacute;ch f&oacute;r',
'rubrique' => 'Rubrika',
'rubriques' => 'Rubriky',

// S
'signatures_petition' => 'Podpisy',
'site_realise_avec_spip' => 'Str&aacute;nky vytvo&#345;eny pomoc&iacute; SPIP',
'sites_web' => 'Odkazy',
'sous_rubriques' => 'Podrubriky',
'spam' => 'Spam',
'suite' => 'pokra&#269;ov&aacute;n&iacute;',
'sur_web' => 'Na webu',
'syndiquer_rubrique' => 'Zahrnout tuto rubriku',
'syndiquer_site' => 'Zahrnout cel&yacute; web',

// T
'texte_lettre_information' => 'Zde je zpravodaj tohoto webu',
'texte_lettre_information_2' => 'Tento soupis sumarizuje &#269;l&aacute;nky a novinky publikovan&eacute; od ',

// V
'ver_imprimer' => 'Verze pro tisk',
'voir_en_ligne' => 'Pod&iacute;vejte se online',
'voir_squelette' => 'Zobrazit &#353;ablonu t&eacute;to str&aacute;nky'
);

?>
